==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebKit2/WebProcess/WebCoreSupport/WebInspectorFrontendClient.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebInspectorFrontendClient_h
#define WebInspectorFrontendClient_h

#if ENABLE(INSPECTOR)

#include <WebCore/InspectorFrontendClientLocal.h>

namespace WebKit {

class WebPage;

class WebInspectorFrontendClient : public WebCore::InspectorFrontendClientLocal {
public:
    WebInspectorFrontendClient(WebPage* page, WebPage* inspectorPage);

private:
    virtual String localizedStringsURL() OVERRIDE;

    virtual void bringToFront() OVERRIDE;
    virtual void closeWindow() OVERRIDE;

    virtual bool canSave() OVERRIDE;
    virtual void save(const String&, const String&, bool base64Encoded, bool forceSaveAs) OVERRIDE;
    virtual void append(const String&, const String&) OVERRIDE;

    virtual void attachWindow(DockSide) OVERRIDE;
    virtual void detachWindow() OVERRIDE;

    virtual void setAttachedWindowHeight(unsigned) OVERRIDE;
    virtual void setAttachedWindowWidth(unsigned) OVERRIDE;
    virtual void setToolbarHeight(unsigned) OVERRIDE;

    virtual void inspectedURLChanged(const String&) OVERRIDE;

    WebPage* m_page;
};

} // namespace WebKit

#endif // ENABLE(INSPECTOR)

#endif // WebInspectorFrontendClient_h

==> webkitgtk_2.3.5.orig.tar.xz: webkitgtk-2.3.5/Source/WebKit2/WebProcess/WebCoreSupport/WebInspectorFrontendClient.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebInspectorFrontendClient_h
#define WebInspectorFrontendClient_h

#if ENABLE(INSPECTOR)

#include <WebCore/InspectorFrontendClientLocal.h>

namespace WebKit {

class WebPage;

class WebInspectorFrontendClient : public WebCore::InspectorFrontendClientLocal {
public:
    WebInspectorFrontendClient(WebPage* page, WebPage* inspectorPage);

private:
    virtual String localizedStringsURL() override;

    virtual void bringToFront() override;
    virtual void closeWindow() override;

    virtual bool canSave() override;
    virtual void save(const String&, const String&, bool base64Encoded, bool forceSaveAs) override;
    virtual void append(const String&, const String&) override;

    virtual void attachWindow(DockSide) override;
    virtual void detachWindow() override;

    virtual void setAttachedWindowHeight(unsigned) override;
    virtual void setAttachedWindowWidth(unsigned) override;
    virtual void setToolbarHeight(unsigned) override;

    virtual void inspectedURLChanged(const String&) override;

    WebPage* m_page;
};

} // namespace WebKit

#endif // ENABLE(INSPECTOR)

#endif // WebInspectorFrontendClient_h
